@@ -113,7 +113,7 @@
 #' if (require("logspline")) {
 #'   prior <- distribution_normal(1000, mean = 0, sd = 1)
 #'   posterior <- distribution_normal(1000, mean = .5, sd = .3)
-#'   (BF_pars <- bayesfactor_parameters(posterior, prior))
+#'   (BF_pars <- bayesfactor_parameters(posterior, prior, verbose = FALSE))
 #'
 #'   as.numeric(BF_pars)
 #' }
@@ -121,34 +121,39 @@
 #' # rstanarm models
 #' # ---------------
 #' if (require("rstanarm") && require("emmeans") && require("logspline")) {
-#'   contrasts(sleep$group) <- contr.orthonorm # see vingette
-#'   stan_model <- stan_lmer(extra ~ group + (1 | ID), data = sleep)
-#'   bayesfactor_parameters(stan_model)
+#'   contrasts(sleep$group) <- contr.equalprior_pairs # see vingette
+#'   stan_model <- suppressWarnings(stan_lmer(
+#'     extra ~ group + (1 | ID),
+#'     data = sleep,
+#'     refresh = 0
+#'   ))
+#'   bayesfactor_parameters(stan_model, verbose = FALSE)
 #'   bayesfactor_parameters(stan_model, null = rope_range(stan_model))
 #'
 #'   # emmGrid objects
 #'   # ---------------
 #'   group_diff <- pairs(emmeans(stan_model, ~group))
-#'   bayesfactor_parameters(group_diff, prior = stan_model)
+#'   bayesfactor_parameters(group_diff, prior = stan_model, verbose = FALSE)
 #'
 #'   # Or
 #'   group_diff_prior <- pairs(emmeans(unupdate(stan_model), ~group))
-#'   bayesfactor_parameters(group_diff, prior = group_diff_prior)
+#'   bayesfactor_parameters(group_diff, prior = group_diff_prior, verbose = FALSE)
 #' }
 #'
 #' # brms models
 #' # -----------
 #' if (require("brms")) {
-#'   contrasts(sleep$group) <- contr.orthonorm # see vingette
+#'   contrasts(sleep$group) <- contr.equalprior_pairs # see vingette
 #'   my_custom_priors <-
 #'     set_prior("student_t(3, 0, 1)", class = "b") +
 #'     set_prior("student_t(3, 0, 1)", class = "sd", group = "ID")
 #'
-#'   brms_model <- brm(extra ~ group + (1 | ID),
+#'   brms_model <- suppressWarnings(brm(extra ~ group + (1 | ID),
 #'     data = sleep,
-#'     prior = my_custom_priors
-#'   )
-#'   bayesfactor_parameters(brms_model)
+#'     prior = my_custom_priors,
+#'     refresh = 0
+#'   ))
+#'   bayesfactor_parameters(brms_model, verbose = FALSE)
 #' }
 #' }
 #' @references
@@ -193,7 +198,7 @@ bayesfactor_pointnull <- function(posterior,
                                   null = 0,
                                   verbose = TRUE,
                                   ...) {
-  if (length(null) > 1) {
+  if (length(null) > 1 && verbose) {
     message("'null' is a range - computing a ROPE based Bayes factor.")
   }
 
@@ -215,8 +220,8 @@ bayesfactor_rope <- function(posterior,
                              null = rope_range(posterior),
                              verbose = TRUE,
                              ...) {
-  if (length(null) < 2) {
-    message("'null' is a point - computing a Savage-Dickey (point null) Bayes factor.")
+  if (length(null) < 2 && verbose) {
+    insight::format_alert("'null' is a point - computing a Savage-Dickey (point null) Bayes factor.")
   }
 
   bayesfactor_parameters(
@@ -249,10 +254,8 @@ bayesfactor_parameters.numeric <- function(posterior, prior = NULL, direction =
   if (is.null(prior)) {
     prior <- posterior
     if (verbose) {
-      warning(
-        "Prior not specified! ",
-        "Please specify a prior (in the form 'prior = distribution_normal(1000, 0, 1)')",
-        " to get meaningful results."
+      insight::format_warning(
+        "Prior not specified! Please specify a prior (in the form 'prior = distribution_normal(1000, 0, 1)') to get meaningful results."
       )
     }
   }
@@ -386,18 +389,17 @@ bayesfactor_parameters.data.frame <- function(posterior,
 
   if (is.null(prior)) {
     prior <- posterior
-    warning(
-      "Prior not specified! ",
-      "Please specify priors (with column order matching 'posterior')",
-      " to get meaningful results."
-    )
+    if (verbose) {
+      insight::format_warning(
+        "Prior not specified! Please specify priors (with column order matching 'posterior') to get meaningful results."
+      )
+    }
   }
 
   if (verbose && length(null) == 1L && (nrow(posterior) < 4e4 || nrow(prior) < 4e4)) {
-    warning(
-      "Bayes factors might not be precise.\n",
-      "For precise Bayes factors, sampling at least 40,000 posterior samples is recommended.",
-      call. = FALSE
+    insight::format_warning(
+      "Bayes factors might not be precise.",
+      "For precise Bayes factors, sampling at least 40,000 posterior samples is recommended."
     )
   }
 
@@ -450,6 +452,8 @@ bayesfactor_parameters.draws <- function(posterior,
   )
 }
 
+#' @export
+bayesfactor_parameters.rvar <- bayesfactor_parameters.draws
 
 
 #' @keywords internal
@@ -482,8 +486,7 @@ bayesfactor_parameters.draws <- function(posterior,
       d_samples / norm_samples
     }
 
-    return(relative_density(prior) /
-      relative_density(posterior))
+    return(relative_density(prior) / relative_density(posterior))
   } else if (length(null) == 2) {
     null <- sort(null)
     null[is.infinite(null)] <- 1.797693e+308 * sign(null[is.infinite(null)])
@@ -516,17 +519,17 @@ bayesfactor_parameters.draws <- function(posterior,
 
 #' @export
 bayesfactor_parameters.bayesfactor_models <- function(...) {
-  stop(
-    "Oh no, 'bayesfactor_parameters()' does not know how to deal with multiple models :(\n",
+  insight::format_error(
+    "Oh no, 'bayesfactor_parameters()' does not know how to deal with multiple models :(",
     "You might want to use 'bayesfactor_inclusion()' here to test specific terms across models."
   )
 }
 
 #' @export
 bayesfactor_parameters.sim <- function(...) {
-  stop(
-    "Bayes factors are based on the shift from a prior to a posterior. ",
-    "Since simulated draws are not based on any priors, computing Bayes factors does not make sense :(\n",
+  insight::format_error(
+    "Bayes factors are based on the shift from a prior to a posterior.",
+    "Since simulated draws are not based on any priors, computing Bayes factors does not make sense :(",
     "You might want to try `rope`, `ci`, `pd` or `pmap` for posterior-based inference."
   )
 }
