@@ -21,7 +21,6 @@
 #' library(bayestestR)
 #'
 #' if (require("ggplot2") && require("rstanarm") && require("ggdist")) {
-#'
 #'   # Generate data =============================================
 #'   k <- 11 # number of curves (iterations)
 #'   n <- 201 # number of rows
@@ -44,12 +43,12 @@
 #'   data[c("ETI_low", "ETI_high")] <- eti(iters, ci = 0.5)[c("CI_low", "CI_high")]
 #'
 #'   # Compute CWI
-#'   # ggdist::curve_interval(reshape_iterations(data), iter_value .width = c(.5))
+#'   # ggdist::curve_interval(reshape_iterations(data), iter_value .width = 0.5)
 #'
 #'   # Visualization =============================================
 #'   ggplot(data, aes(x = x, y = Median)) +
 #'     geom_ribbon(aes(ymin = ETI_low, ymax = ETI_high), fill = "red", alpha = 0.3) +
-#'     geom_line(size = 1) +
+#'     geom_line(linewidth = 1) +
 #'     geom_line(
 #'       data = reshape_iterations(data),
 #'       aes(y = iter_value, group = iter_group),
@@ -68,5 +67,5 @@ cwi <- function(x, ...) {
 cwi.data.frame <- function(x, ci = 0.95, ...) {
   insight::check_if_installed("ggdist")
 
-  print("Comming soon!")
+  print("Comming soon!") # @DominiqueMakowski GitBlame says this was 2 years ago - when is "soon"? :-)
 }
