@@ -108,11 +108,17 @@ print.bayestestR_hdi <- function(x,
                                  digits = 2,
                                  caption = "Highest Density Interval",
                                  ...) {
+  ci_string <- "HDI"
+  if (inherits(x, "bayestestR_spi")) {
+    caption <- "Shortest Probability Interval"
+    ci_string <- "SPI"
+  }
+
   .print_default(
     x = x,
     digits = digits,
     caption = caption,
-    ci_string = "HDI",
+    ci_string = ci_string,
     ...
   )
 }
@@ -165,7 +171,7 @@ print.bayesfactor_models <- function(x,
     log = log,
     show_names = show_names,
     caption = caption,
-    align = c("llr"),
+    align = "llr",
     ...
   )
 }
@@ -205,7 +211,6 @@ print.bayesfactor_restricted <- function(x,
 
 #' @export
 print.bayesfactor_parameters <- function(x, digits = 3, log = FALSE, ...) {
-
   # retrieve information with cleaned parameter names
   cp <- attr(x, "clean_parameters")
 
@@ -233,8 +238,6 @@ print.bayesfactor_parameters <- function(x, digits = 3, log = FALSE, ...) {
                            subtitles = NULL,
                            ci_string = "CI",
                            ...) {
-
-
   # retrieve information with cleaned parameter names
   cp <- attr(x, "clean_parameters")
 
@@ -252,20 +255,18 @@ print.bayesfactor_parameters <- function(x, digits = 3, log = FALSE, ...) {
 
   # check if we have a 1x1 data frame (i.e. a numeric input)
   if (is.data.frame(formatted_table) && nrow(formatted_table) == 1 && ncol(formatted_table) == 1) {
-
     # print for numeric
 
     caption <- attr(formatted_table, "table_caption")
 
     # if we have no useful column name and a caption, use caption
-    if (!is.null(caption) && !grepl(paste0(ci_string, "$"), colnames(formatted_table))) {
+    if (!is.null(caption) && !endsWith(colnames(formatted_table), ci_string)) {
       cat(paste0(caption, ": "))
     } else {
       cat(paste0(colnames(formatted_table), ": "))
     }
     cat(formatted_table[1, 1])
   } else {
-
     # print for data frame
 
     cat(insight::export_table(
@@ -285,7 +286,6 @@ print.bayesfactor_parameters <- function(x, digits = 3, log = FALSE, ...) {
                               caption = NULL,
                               align = NULL,
                               ...) {
-
   # format data frame and columns
   formatted_table <- format(
     x,
