@@ -11,8 +11,10 @@
 #' variables. If `"default"` and input is a vector, the range is set to `c(-0.1,
 #' 0.1)`. If `"default"` and input is a Bayesian model,
 #' [`rope_range()`][rope_range] is used.
-#' @param ci The Credible Interval (CI) probability, corresponding to the proportion of HDI, to use for the percentage in ROPE.
-#' @param ci_method The type of interval to use to quantify the percentage in ROPE. Can be 'HDI' (default) or 'ETI'. See [ci()].
+#' @param ci The Credible Interval (CI) probability, corresponding to the
+#'   proportion of HDI, to use for the percentage in ROPE.
+#' @param ci_method The type of interval to use to quantify the percentage in
+#'   ROPE. Can be 'HDI' (default) or 'ETI'. See [ci()].
 #'
 #' @inheritParams hdi
 #'
@@ -179,7 +181,7 @@ rope.data.frame <- function(x, range = "default", ci = 0.95, ci_method = "ETI",
   row.names(dat) <- NULL
 
   attr(dat, "HDI_area") <- HDI_area_attributes
-  attr(dat, "object_name") <- insight::safe_deparse(substitute(x))
+  attr(dat, "object_name") <- insight::safe_deparse_symbol(substitute(x))
 
   class(dat) <- c("rope", "see_rope", "data.frame")
   dat
@@ -202,7 +204,7 @@ rope.emmGrid <- function(x, range = "default", ci = 0.95, ci_method = "ETI", ver
   xdf <- insight::get_parameters(x)
 
   dat <- rope(xdf, range = range, ci = ci, ci_method = ci_method, verbose = verbose, ...)
-  attr(dat, "object_name") <- insight::safe_deparse(substitute(x))
+  attr(dat, "object_name") <- insight::safe_deparse_symbol(substitute(x))
   dat
 }
 
@@ -217,7 +219,7 @@ rope.BFBayesFactor <- function(x, range = "default", ci = 0.95, ci_method = "ETI
     range <- rope_range(x, verbose = verbose)
   }
   out <- rope(insight::get_parameters(x), range = range, ci = ci, ci_method = ci_method, verbose = verbose, ...)
-  attr(out, "object_name") <- insight::safe_deparse(substitute(x))
+  attr(out, "object_name") <- insight::safe_deparse_symbol(substitute(x))
   out
 }
 
@@ -230,7 +232,7 @@ rope.bamlss <- rope.BFBayesFactor
 rope.MCMCglmm <- function(x, range = "default", ci = 0.95, ci_method = "ETI", verbose = TRUE, ...) {
   nF <- x$Fixed$nfl
   out <- rope(as.data.frame(x$Sol[, 1:nF, drop = FALSE]), range = range, ci = ci, ci_method = ci_method, verbose = verbose, ...)
-  attr(out, "object_name") <- insight::safe_deparse(substitute(x))
+  attr(out, "object_name") <- insight::safe_deparse_symbol(substitute(x))
   out
 }
 
@@ -239,7 +241,7 @@ rope.MCMCglmm <- function(x, range = "default", ci = 0.95, ci_method = "ETI", ve
 rope.mcmc <- function(x, range = "default", ci = 0.95, ci_method = "ETI", verbose = TRUE, ...) {
   out <- rope(as.data.frame(x), range = range, ci = ci, ci_method = ci_method, verbose = verbose, ...)
   attr(out, "object_name") <- NULL
-  attr(out, "data") <- insight::safe_deparse(substitute(x))
+  attr(out, "data") <- insight::safe_deparse_symbol(substitute(x))
   out
 }
 
@@ -248,7 +250,7 @@ rope.mcmc <- function(x, range = "default", ci = 0.95, ci_method = "ETI", verbos
 rope.bcplm <- function(x, range = "default", ci = 0.95, ci_method = "ETI", verbose = TRUE, ...) {
   out <- rope(insight::get_parameters(x), range = range, ci = ci, ci_method = ci_method, verbose = verbose, ...)
   attr(out, "object_name") <- NULL
-  attr(out, "data") <- insight::safe_deparse(substitute(x))
+  attr(out, "data") <- insight::safe_deparse_symbol(substitute(x))
   out
 }
 
@@ -303,7 +305,7 @@ rope.stanreg <- function(x, range = "default", ci = 0.95, ci_method = "ETI", eff
   if (all(range == "default")) {
     range <- rope_range(x, verbose = verbose)
   } else if (!all(is.numeric(range)) || length(range) != 2) {
-    stop("`range` should be 'default' or a vector of 2 numeric values (e.g., c(-0.1, 0.1)).", call. = FALSE)
+    insight::format_error("`range` should be 'default' or a vector of 2 numeric values (e.g., c(-0.1, 0.1)).")
   }
 
   # check for possible collinearity that might bias ROPE
@@ -321,7 +323,7 @@ rope.stanreg <- function(x, range = "default", ci = 0.95, ci_method = "ETI", eff
   out <- .prepare_output(rope_data, insight::clean_parameters(x), inherits(x, "stanmvreg"))
 
   attr(out, "HDI_area") <- attr(rope_data, "HDI_area")
-  attr(out, "object_name") <- insight::safe_deparse(substitute(x))
+  attr(out, "object_name") <- insight::safe_deparse_symbol(substitute(x))
   class(out) <- class(rope_data)
 
   out
@@ -411,7 +413,7 @@ rope.brmsfit <- function(x,
   }
 
   attr(out, "HDI_area") <- attr(rope_data, "HDI_area")
-  attr(out, "object_name") <- insight::safe_deparse(substitute(x))
+  attr(out, "object_name") <- insight::safe_deparse_symbol(substitute(x))
   class(out) <- class(rope_data)
 
   out
@@ -475,7 +477,7 @@ rope.sim.merMod <- function(x, range = "default", ci = 0.95, ci_method = "ETI",
   }
 
   attr(dat, "HDI_area") <- HDI_area_attributes
-  attr(dat, "object_name") <- insight::safe_deparse(substitute(x))
+  attr(dat, "object_name") <- insight::safe_deparse_symbol(substitute(x))
 
   dat
 }
@@ -511,7 +513,7 @@ rope.sim <- function(x, range = "default", ci = 0.95, ci_method = "ETI", paramet
     dat <- NULL
   }
 
-  attr(dat, "object_name") <- insight::safe_deparse(substitute(x))
+  attr(dat, "object_name") <- insight::safe_deparse_symbol(substitute(x))
 
   dat
 }
@@ -531,9 +533,7 @@ rope.sim <- function(x, range = "default", ci = 0.95, ci_method = "ETI", paramet
     simplify = FALSE
   )
 
-  HDI_area <- lapply(tmp, function(.x) {
-    attr(.x, "HDI_area")
-  })
+  HDI_area <- lapply(tmp, attr, which = "HDI_area")
 
   # HDI_area <- lapply(HDI_area, function(.x) {
   #   dat <- cbind(CI = ci, data.frame(do.call(rbind, .x)))
